# Code samples for the Revit Batch Processor
This repository contains python code samples for the [Revit Batch Processor](https://github.com/bvn-architecture/RevitBatchProcessor)

A more detailed description of the varies modules, can be found in the online [docs](https://jchristel.github.io/SampleCodeRevitBatchProcessor/) and in the [wiki](https://github.com/jchristel/SampleCodeRevitBatchProcessor/wiki).

## Sample code via pip
The DuHast is now available as a pip install:
```
pip install DuHast
```

This is currently still experimental only. The sample flows will be upgraded to use this package once its considered stable. 
